@@ -1,12 +1,11 @@
 
 
 from __future__ import annotations
-from dataclasses import dataclass
+import dataclasses
 import numpy as np
-from typing import Union, Type
 
 
-@dataclass
+@dataclasses.dataclass
 class Huffman:
     bits: np.ndarray
     """bits used to represent number of elements"""
@@ -19,11 +18,6 @@ class Huffman:
     #     print(self.values)
     #     assert len(self.values) == np.sum(self.bits), 'invalid histogram'
 
-    @property
-    def bits(self) -> int:
-        """Index getter."""
-        return self.name_to_index(self.name)
-
     @property
     def bits(self) -> str:
         """Name getter."""
